==> open-xchange-mail-categories_7.8.2.orig.tar.bz2: open-xchange-mail-categories-7.8.2/com.openexchange.mail.categories.impl/src/com/openexchange/mail/categories/impl/MailCategoriesLoginHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.categories.impl;

import com.openexchange.ajax.Client;
import com.openexchange.exception.OXException;
import com.openexchange.login.LoginHandlerService;
import com.openexchange.login.LoginResult;
import com.openexchange.session.Session;

/**
 * {@link MailCategoriesLoginHandler} initializes the MailCategoriesRuleEngine if it is the first login after activation.
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.2
 */
public class MailCategoriesLoginHandler implements LoginHandlerService {

    private final MailCategoriesConfigServiceImpl mailCategoriesService;

    /**
     * Initializes a new {@link MailCategoriesLoginHandler}.
     */
    public MailCategoriesLoginHandler(MailCategoriesConfigServiceImpl mailCategoriesService) {
        super();
        this.mailCategoriesService = mailCategoriesService;
    }

    @Override
    public void handleLogin(LoginResult login) throws OXException {
        Session session = login.getSession();
        if (false == Client.isAppSuiteUI(session)) {
            return;
        }

        mailCategoriesService.initMailCategories(session);
    }

    @Override
    public void handleLogout(LoginResult logout) throws OXException {
        // nothing to do
    }

}

==> open-xchange-mail-categories_7.10.1.orig.tar.bz2: open-xchange-mail-categories-7.10.1/com.openexchange.mail.categories.impl/src/com/openexchange/mail/categories/impl/MailCategoriesLoginHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.categories.impl;

import com.openexchange.ajax.Client;
import com.openexchange.exception.OXException;
import com.openexchange.login.LoginHandlerService;
import com.openexchange.login.LoginResult;
import com.openexchange.session.Session;

/**
 * {@link MailCategoriesLoginHandler} initializes the MailCategoriesRuleEngine if it is the first login after activation.
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.2
 */
public class MailCategoriesLoginHandler implements LoginHandlerService {

    private final MailCategoriesConfigServiceImpl mailCategoriesService;

    /**
     * Initializes a new {@link MailCategoriesLoginHandler}.
     */
    public MailCategoriesLoginHandler(MailCategoriesConfigServiceImpl mailCategoriesService) {
        super();
        this.mailCategoriesService = mailCategoriesService;
    }

    @Override
    public void handleLogin(LoginResult login) throws OXException {
        Session session = login.getSession();
        if (false == Client.isAppSuiteUI(session)) {
            return;
        }

        mailCategoriesService.initMailCategories(session);
    }

    @Override
    public void handleLogout(LoginResult logout) {
        // nothing to do
    }

}
